qmap_close

Function qmap_close 

pub unsafe extern "C" fn qmap_close(hd: u32)
@brief Close a map and free its resources.

Deletes all entries, closes associated secondary maps, and frees internal structures. All open maps are automatically closed at process exit by the library destructor, but you can call this explicitly to free resources earlier.

@param[in] hd Handle to close.