pub struct Qmap { /* private fields */ }Expand description
Safe wrapper for a Qmap handle.
Implementations
Sourceimpl Qmap
impl Qmap
pub fn open( filename: Option<&str>, database: Option<&str>, ktype: u32, vtype: u32, mask: u32, flags: u32, ) -> Option<Self>
pub fn handle(&self) -> u32
Sourcepub unsafe fn from_handle(hd: u32) -> Self
pub unsafe fn from_handle(hd: u32) -> Self
Creates a Qmap handle from a raw handle ID. This should only be used for handles managed elsewhere (like in ndc C backend).
pub fn get(&self, key: *const c_void) -> *const c_void
pub fn get_str(&self, key: &str) -> Option<&str>
pub fn put(&self, key: *const c_void, value: *const c_void) -> u32
pub fn put_str(&self, key: &str, value: &str) -> u32
pub fn del(&self, key: *const c_void)
pub fn drop(&self)
pub fn iter(&self, key: *const c_void, flags: u32) -> Cursor