pub unsafe extern "C" fn qmap_save()Expand description
@brief Write all file-backed maps to disk.
Walks the internal cache, computes file sizes, and performs mmap/memcpy writes for maps associated with a file.
@note This is automatically called at process exit. Explicit calls are only needed for mid-execution checkpointing or when you want to ensure data is persisted before continuing.